@@ -14,7 +14,7 @@
 #include "compiled.h"    // GAP headers
 
 #if GAP_KERNEL_MAJOR_VERSION >= 6
-#include "src/profile.h"
+#include "profile.h"
 #endif
 
 #undef PACKAGE
@@ -1777,6 +1777,10 @@ static Obj FuncIO_gmtime(Obj self, Obj time)
     Obj         tmp;
     time_t      t;
     struct tm * s;
+    if (!IS_INT(time)) {
+        SyClearErrorNo();
+        return Fail;
+    }
     if (!IS_INTOBJ(time)) {
         tmp = QuoInt(time, INTOBJ_INT(256));
         if (!IS_INTOBJ(tmp))
@@ -1808,6 +1812,10 @@ static Obj FuncIO_localtime(Obj self, Obj time)
     Obj         tmp;
     time_t      t;
     struct tm * s;
+    if (!IS_INT(time)) {
+        SyClearErrorNo();
+        return Fail;
+    }
     if (!IS_INTOBJ(time)) {
         tmp = QuoInt(time, INTOBJ_INT(256));
         if (!IS_INTOBJ(tmp))
